import dataFetched from './dataFetched';

import type {
    FoundationDataProviderResult,
} from './types';


interface TestData {
    text1: string;
    text2: string;
}

test('should set all data when transitioning from fetching-initial to success', () => {
    const result: FoundationDataProviderResult<TestData> = {
        state: 'fetching-initial',
    };

    const callback = dataFetched<TestData>({
        text1: '#1',
        text2: '#2',
    });

    const newResult = callback(result);

    expect(newResult).toEqual({
        data: {
            text1: '#1',
            text2: '#2',
        },
        state: 'success',
    });
});

test('can set all data when transitioning from fetching to success', () => {
    const result: FoundationDataProviderResult<TestData> = {
        data: {
            text1: '#1',
            text2: '#2',
        },
        state: 'fetching',
    };

    const callback = dataFetched<Partial<TestData>>({
        text1: 'updated #1',
        text2: 'updated #2',
    });

    const newResult = callback(result);

    expect(newResult).toEqual({
        data: {
            text1: 'updated #1',
            text2: 'updated #2',
        },
        state: 'success',
    });
});

test('can set partial data when transitioning from fetching to success', () => {
    const result: FoundationDataProviderResult<TestData> = {
        data: {
            text1: '#1',
            text2: '#2',
        },
        state: 'fetching',
    };

    const callback = dataFetched<Partial<TestData>>({
        text1: 'updated #1',
    });

    const newResult = callback(result);

    expect(newResult).toEqual({
        data: {
            text1: 'updated #1',
            text2: '#2',
        },
        state: 'success',
    });
});
