import dataUpdate from './dataUpdate';

import type {
    FoundationDataProviderFetchState,
    FoundationDataProviderResult,
} from './types';


interface TestData {
    text1: string;
    text2: string;
}

test.each<FoundationDataProviderFetchState>([
    'error',
    'error-initial',
    'fetching',
    'fetching-initial',
])('should not update when in %s state', (fetchMode) => {
    const result: FoundationDataProviderResult<TestData> = {
        data: {
            text1: '#1',
            text2: '#2',
        },
        errors: {},
        state: fetchMode,
    };

    const callback = dataUpdate<TestData>({
        text1: 'updated #1',
        text2: 'updated #2',
    });

    const newResult = callback(result);

    expect(newResult).toEqual(result);
});

test.each<FoundationDataProviderFetchState>([
    'success',
])('should be able to update data when in %s state', (fetchMode) => {
    const result: FoundationDataProviderResult<TestData> = {
        data: {
            text1: '#1',
            text2: '#2',
        },
        errors: {},
        state: fetchMode,
    };

    const callback = dataUpdate<TestData>({
        text1: 'updated #1',
        text2: 'updated #2',
    });

    const newResult = callback(result);

    expect(newResult).toEqual({
        data: {
            text1: 'updated #1',
            text2: 'updated #2',
        },
        errors: {},
        state: fetchMode,
    });
});

test.each<FoundationDataProviderFetchState>([
    'success',
])('should be able to partially update data when in %s state', (fetchMode) => {
    const result: FoundationDataProviderResult<TestData> = {
        data: {
            text1: '#1',
            text2: '#2',
        },
        errors: {},
        state: fetchMode,
    };

    const callback = dataUpdate<TestData>({
        text1: 'updated #1',
    });

    const newResult = callback(result);

    expect(newResult).toEqual({
        data: {
            text1: 'updated #1',
            text2: '#2',
        },
        errors: {},
        state: fetchMode,
    });
});
